# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarPlaceLinkRequest(Model):
    """EnergyStarPlaceLinkRequest.

    :param pm_property_id: The Portfolio Manager property identifier.  Set to
     null to unlink place. <span class='property-internal'>Required
     (defined)</span>
    :type pm_property_id: long
    :param meters: List of meter links for this place
     If PmPropertyId is null to unlink the place then Meters should null.
     All meters under the place will be unlinked automatically. <span
     class='property-internal'>Required (defined)</span>
    :type meters: list[~energycap.sdk.models.EnergyStarMeterLinkRequest]
    """

    _attribute_map = {
        'pm_property_id': {'key': 'pmPropertyId', 'type': 'long'},
        'meters': {'key': 'meters', 'type': '[EnergyStarMeterLinkRequest]'},
    }

    def __init__(self, **kwargs):
        super(EnergyStarPlaceLinkRequest, self).__init__(**kwargs)
        self.pm_property_id = kwargs.get('pm_property_id', None)
        self.meters = kwargs.get('meters', None)
