# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DataTypeResponse(Model):
    """DataTypeResponse.

    :param data_type_id:  <span class='property-internal'>Required
     (defined)</span>
    :type data_type_id: int
    :param data_type_code:  <span class='property-internal'>Required
     (defined)</span>
    :type data_type_code: str
    :param data_type_info:  <span class='property-internal'>Required
     (defined)</span>
    :type data_type_info: str
    """

    _attribute_map = {
        'data_type_id': {'key': 'dataTypeId', 'type': 'int'},
        'data_type_code': {'key': 'dataTypeCode', 'type': 'str'},
        'data_type_info': {'key': 'dataTypeInfo', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(DataTypeResponse, self).__init__(**kwargs)
        self.data_type_id = kwargs.get('data_type_id', None)
        self.data_type_code = kwargs.get('data_type_code', None)
        self.data_type_info = kwargs.get('data_type_info', None)
