# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PrimaryUseCreate(Model):
    """PrimaryUseCreate.

    All required parameters must be populated in order to send to Azure.

    :param primary_use_code: Required. The Primary Use Code <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 64 characters</span>
    :type primary_use_code: str
    :param primary_use_info: Required. The Primary Use Info <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 64 characters</span>
    :type primary_use_info: str
    :param primary_use_type: Required. The Primary Use Type. Possible value
     include: "place" and "meter" <span
     class='property-internal'>Required</span> <span
     class='property-internal'>One of place, meter </span>
    :type primary_use_type: str
    """

    _validation = {
        'primary_use_code': {'required': True, 'max_length': 64, 'min_length': 0},
        'primary_use_info': {'required': True, 'max_length': 64, 'min_length': 0},
        'primary_use_type': {'required': True},
    }

    _attribute_map = {
        'primary_use_code': {'key': 'primaryUseCode', 'type': 'str'},
        'primary_use_info': {'key': 'primaryUseInfo', 'type': 'str'},
        'primary_use_type': {'key': 'primaryUseType', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(PrimaryUseCreate, self).__init__(**kwargs)
        self.primary_use_code = kwargs.get('primary_use_code', None)
        self.primary_use_info = kwargs.get('primary_use_info', None)
        self.primary_use_type = kwargs.get('primary_use_type', None)
