# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FixedUseRequest(Model):
    """FixedUseRequest.

    All required parameters must be populated in order to send to Azure.

    :param fixed_use_amount: Required. Fixed use amount <span
     class='property-internal'>Required</span> <span class='property-info'>Max
     scale of 6</span>
    :type fixed_use_amount: float
    :param unit_id: Required. Unit to which use is applied <span
     class='property-internal'>Required</span>
    :type unit_id: int
    """

    _validation = {
        'fixed_use_amount': {'required': True},
        'unit_id': {'required': True},
    }

    _attribute_map = {
        'fixed_use_amount': {'key': 'fixedUseAmount', 'type': 'float'},
        'unit_id': {'key': 'unitId', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(FixedUseRequest, self).__init__(**kwargs)
        self.fixed_use_amount = kwargs.get('fixed_use_amount', None)
        self.unit_id = kwargs.get('unit_id', None)
