# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillSplitPlaceSizeChild(Model):
    """BillSplitPlaceSizeChild.

    :param place_size_id:
    :type place_size_id: int
    :param begin_date:
    :type begin_date: datetime
    :param end_date:
    :type end_date: datetime
    :param value:
    :type value: float
    :param unit:
    :type unit: ~energycap.sdk.models.UnitChild
    """

    _attribute_map = {
        'place_size_id': {'key': 'placeSizeId', 'type': 'int'},
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'value': {'key': 'value', 'type': 'float'},
        'unit': {'key': 'unit', 'type': 'UnitChild'},
    }

    def __init__(self, **kwargs):
        super(BillSplitPlaceSizeChild, self).__init__(**kwargs)
        self.place_size_id = kwargs.get('place_size_id', None)
        self.begin_date = kwargs.get('begin_date', None)
        self.end_date = kwargs.get('end_date', None)
        self.value = kwargs.get('value', None)
        self.unit = kwargs.get('unit', None)
