# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class QuickFilter(Model):
    """QuickFilter.

    All required parameters must be populated in order to send to Azure.

    :param caption: Required.  <span class='property-internal'>Required</span>
    :type caption: str
    :param operator: Required.  <span
     class='property-internal'>Required</span>
    :type operator: str
    :param value: Required.  <span class='property-internal'>Required</span>
    :type value: str
    """

    _validation = {
        'caption': {'required': True},
        'operator': {'required': True},
        'value': {'required': True},
    }

    _attribute_map = {
        'caption': {'key': 'caption', 'type': 'str'},
        'operator': {'key': 'operator', 'type': 'str'},
        'value': {'key': 'value', 'type': 'str'},
    }

    def __init__(self, *, caption: str, operator: str, value: str, **kwargs) -> None:
        super(QuickFilter, self).__init__(**kwargs)
        self.caption = caption
        self.operator = operator
        self.value = value
