# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TimeZoneResponse(Model):
    """TimeZoneResponse.

    :param time_zone_id: The time zone id
    :type time_zone_id: int
    :param time_zone_code: The time zone code
    :type time_zone_code: str
    :param time_zone_info: The time zone info
    :type time_zone_info: str
    :param gmt_offset: The time zone gmt offset
    :type gmt_offset: float
    :param daylight_savings_observed: Indicates if the time zone observes
     daylight savings time or not
    :type daylight_savings_observed: bool
    """

    _attribute_map = {
        'time_zone_id': {'key': 'timeZoneId', 'type': 'int'},
        'time_zone_code': {'key': 'timeZoneCode', 'type': 'str'},
        'time_zone_info': {'key': 'timeZoneInfo', 'type': 'str'},
        'gmt_offset': {'key': 'gmtOffset', 'type': 'float'},
        'daylight_savings_observed': {'key': 'daylightSavingsObserved', 'type': 'bool'},
    }

    def __init__(self, *, time_zone_id: int=None, time_zone_code: str=None, time_zone_info: str=None, gmt_offset: float=None, daylight_savings_observed: bool=None, **kwargs) -> None:
        super(TimeZoneResponse, self).__init__(**kwargs)
        self.time_zone_id = time_zone_id
        self.time_zone_code = time_zone_code
        self.time_zone_info = time_zone_info
        self.gmt_offset = gmt_offset
        self.daylight_savings_observed = daylight_savings_observed
