# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SystemUserRoleResponse(Model):
    """SystemUserRoleResponse.

    :param system_user_role_id: Identifier for the system user role
    :type system_user_role_id: int
    :param system_user_role_name: Name of the system user role
    :type system_user_role_name: str
    :param description: Description of the system user role
    :type description: str
    :param users_assigned_count: Number of users currently assigned to the
     system user role
    :type users_assigned_count: int
    :param permissions:
    :type permissions: ~energycap.sdk.models.Permissions
    :param read_only: Indicates the system user role that cannot be modified
     These roles can be hidden using the SetUserRoleHidden API
    :type read_only: bool
    :param hidden: Hidden status of the system user role
     Roles Manage permission is required to access hidden roles
    :type hidden: bool
    """

    _attribute_map = {
        'system_user_role_id': {'key': 'systemUserRoleId', 'type': 'int'},
        'system_user_role_name': {'key': 'systemUserRoleName', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'users_assigned_count': {'key': 'usersAssignedCount', 'type': 'int'},
        'permissions': {'key': 'permissions', 'type': 'Permissions'},
        'read_only': {'key': 'readOnly', 'type': 'bool'},
        'hidden': {'key': 'hidden', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(SystemUserRoleResponse, self).__init__(**kwargs)
        self.system_user_role_id = kwargs.get('system_user_role_id', None)
        self.system_user_role_name = kwargs.get('system_user_role_name', None)
        self.description = kwargs.get('description', None)
        self.users_assigned_count = kwargs.get('users_assigned_count', None)
        self.permissions = kwargs.get('permissions', None)
        self.read_only = kwargs.get('read_only', None)
        self.hidden = kwargs.get('hidden', None)
