# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UDFSelectValueUpdate(Model):
    """UDFSelectValueUpdate.

    All required parameters must be populated in order to send to Azure.

    :param udf_select_value_id: The UDF select value identifier. When creating
     a new option, assign null to this property. <span
     class='property-internal'>Required (defined)</span>
    :type udf_select_value_id: int
    :param value: Required. The UDF select option's value <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 255 characters</span>
    :type value: str
    """

    _validation = {
        'value': {'required': True, 'max_length': 255, 'min_length': 0},
    }

    _attribute_map = {
        'udf_select_value_id': {'key': 'udfSelectValueId', 'type': 'int'},
        'value': {'key': 'value', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(UDFSelectValueUpdate, self).__init__(**kwargs)
        self.udf_select_value_id = kwargs.get('udf_select_value_id', None)
        self.value = kwargs.get('value', None)
