# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UserChildWithEmail(Model):
    """UserChildWithEmail.

    :param email: Email ID of the user
    :type email: str
    :param user_id: The user identifier
    :type user_id: int
    :param user_code: The user code
    :type user_code: str
    :param full_name: The user's full name
    :type full_name: str
    """

    _attribute_map = {
        'email': {'key': 'email', 'type': 'str'},
        'user_id': {'key': 'userId', 'type': 'int'},
        'user_code': {'key': 'userCode', 'type': 'str'},
        'full_name': {'key': 'fullName', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(UserChildWithEmail, self).__init__(**kwargs)
        self.email = kwargs.get('email', None)
        self.user_id = kwargs.get('user_id', None)
        self.user_code = kwargs.get('user_code', None)
        self.full_name = kwargs.get('full_name', None)
