# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarPlaceMetricsResponse(Model):
    """EnergyStarPlaceMetricsResponse.

    :param calendar_period: The year and month for the ENERGY STAR score
    :type calendar_period: int
    :param score: The ENERGY STAR score
    :type score: int
    :param date_received: The date the score was received
    :type date_received: datetime
    :param site_energy_use: The weather-normalized property energy use (kBtu)
    :type site_energy_use: float
    :param site_energy_use_intensity: The weather-normalized property energy
     use intensity (kBtu/ft²)
    :type site_energy_use_intensity: float
    :param national_median_score: The national median ENERGY STAR score for
     the same type of property
    :type national_median_score: int
    :param national_median_site_energy_use_intensity: The national median
     weather-normalized property energy use intensity (kBtu/ft²)
    :type national_median_site_energy_use_intensity: float
    :param pct_diff_national_median_site_energy_use_intensity: The percent
     difference in the property energy use intensity vs. the national median
    :type pct_diff_national_median_site_energy_use_intensity: float
    """

    _attribute_map = {
        'calendar_period': {'key': 'calendarPeriod', 'type': 'int'},
        'score': {'key': 'score', 'type': 'int'},
        'date_received': {'key': 'dateReceived', 'type': 'iso-8601'},
        'site_energy_use': {'key': 'siteEnergyUse', 'type': 'float'},
        'site_energy_use_intensity': {'key': 'siteEnergyUseIntensity', 'type': 'float'},
        'national_median_score': {'key': 'nationalMedianScore', 'type': 'int'},
        'national_median_site_energy_use_intensity': {'key': 'nationalMedianSiteEnergyUseIntensity', 'type': 'float'},
        'pct_diff_national_median_site_energy_use_intensity': {'key': 'pctDiffNationalMedianSiteEnergyUseIntensity', 'type': 'float'},
    }

    def __init__(self, *, calendar_period: int=None, score: int=None, date_received=None, site_energy_use: float=None, site_energy_use_intensity: float=None, national_median_score: int=None, national_median_site_energy_use_intensity: float=None, pct_diff_national_median_site_energy_use_intensity: float=None, **kwargs) -> None:
        super(EnergyStarPlaceMetricsResponse, self).__init__(**kwargs)
        self.calendar_period = calendar_period
        self.score = score
        self.date_received = date_received
        self.site_energy_use = site_energy_use
        self.site_energy_use_intensity = site_energy_use_intensity
        self.national_median_score = national_median_score
        self.national_median_site_energy_use_intensity = national_median_site_energy_use_intensity
        self.pct_diff_national_median_site_energy_use_intensity = pct_diff_national_median_site_energy_use_intensity
