# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class OutlierSeverityChild(Model):
    """OutlierSeverityChild.

    :param outlier_severity: The integer that represents the severity of the
     outlier
     Values: 1, 2, 3, or 4
    :type outlier_severity: int
    :param outlier_severity_info: The information regarding the current
     outlier severity
     Values: 1 = Severe, 2 = High, 3 = Moderate, 4 = Cannot be determined
     Severe - Actual value is 1, standard deviation > 3.0 on the high side or >
     5.0 on the low side
     High - Actual value is 2, standard deviation > 2.0 high and > 4.0 low
     Moderate - Actual value is 3, standard deviation > 1.5 high and > 3.0 low
     Not Classified - It is not one of Severe, High, Low or the model could not
     be determined
    :type outlier_severity_info: str
    """

    _attribute_map = {
        'outlier_severity': {'key': 'outlierSeverity', 'type': 'int'},
        'outlier_severity_info': {'key': 'outlierSeverityInfo', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(OutlierSeverityChild, self).__init__(**kwargs)
        self.outlier_severity = kwargs.get('outlier_severity', None)
        self.outlier_severity_info = kwargs.get('outlier_severity_info', None)
