# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DistributeAccountChargesBase(Model):
    """DistributeAccountChargesBase.

    :param split_basis:
    :type split_basis: int
    """

    _attribute_map = {
        'split_basis': {'key': 'splitBasis', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(DistributeAccountChargesBase, self).__init__(**kwargs)
        self.split_basis = kwargs.get('split_basis', None)
