# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AddressLookup(Model):
    """AddressLookup.

    :param address_type_id:
    :type address_type_id: int
    :param line1:
    :type line1: str
    :param line2:
    :type line2: str
    :param line3:
    :type line3: str
    :param city:
    :type city: str
    :param state:
    :type state: str
    :param country:
    :type country: str
    :param postal_code:
    :type postal_code: str
    :param latitude:
    :type latitude: float
    :param longitude:
    :type longitude: float
    :param unique_location_identifier:
    :type unique_location_identifier: str
    :param location_properties:
    :type location_properties: dict[str, object]
    """

    _attribute_map = {
        'address_type_id': {'key': 'addressTypeId', 'type': 'int'},
        'line1': {'key': 'line1', 'type': 'str'},
        'line2': {'key': 'line2', 'type': 'str'},
        'line3': {'key': 'line3', 'type': 'str'},
        'city': {'key': 'city', 'type': 'str'},
        'state': {'key': 'state', 'type': 'str'},
        'country': {'key': 'country', 'type': 'str'},
        'postal_code': {'key': 'postalCode', 'type': 'str'},
        'latitude': {'key': 'latitude', 'type': 'float'},
        'longitude': {'key': 'longitude', 'type': 'float'},
        'unique_location_identifier': {'key': 'uniqueLocationIdentifier', 'type': 'str'},
        'location_properties': {'key': 'locationProperties', 'type': '{object}'},
    }

    def __init__(self, *, address_type_id: int=None, line1: str=None, line2: str=None, line3: str=None, city: str=None, state: str=None, country: str=None, postal_code: str=None, latitude: float=None, longitude: float=None, unique_location_identifier: str=None, location_properties=None, **kwargs) -> None:
        super(AddressLookup, self).__init__(**kwargs)
        self.address_type_id = address_type_id
        self.line1 = line1
        self.line2 = line2
        self.line3 = line3
        self.city = city
        self.state = state
        self.country = country
        self.postal_code = postal_code
        self.latitude = latitude
        self.longitude = longitude
        self.unique_location_identifier = unique_location_identifier
        self.location_properties = location_properties
