# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MostRecentAggregate(Model):
    """MostRecentAggregate.

    :param aggregate_meter_id: The identifier of the aggregate meter
    :type aggregate_meter_id: int
    :param effective_date: The effective date of the aggregation
    :type effective_date: datetime
    """

    _attribute_map = {
        'aggregate_meter_id': {'key': 'aggregateMeterId', 'type': 'int'},
        'effective_date': {'key': 'effectiveDate', 'type': 'iso-8601'},
    }

    def __init__(self, **kwargs):
        super(MostRecentAggregate, self).__init__(**kwargs)
        self.aggregate_meter_id = kwargs.get('aggregate_meter_id', None)
        self.effective_date = kwargs.get('effective_date', None)
