# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MoveCreateMeter(Model):
    """MoveCreateMeter.

    :param meter_code: The meter code
    :type meter_code: str
    :param meter_display: The meter display name
    :type meter_display: str
    :param commodity:
    :type commodity: ~energycap.sdk.models.CommodityChild
    :param serial_number: The meter serial number
    :type serial_number: str
    """

    _attribute_map = {
        'meter_code': {'key': 'meterCode', 'type': 'str'},
        'meter_display': {'key': 'meterDisplay', 'type': 'str'},
        'commodity': {'key': 'commodity', 'type': 'CommodityChild'},
        'serial_number': {'key': 'serialNumber', 'type': 'str'},
    }

    def __init__(self, *, meter_code: str=None, meter_display: str=None, commodity=None, serial_number: str=None, **kwargs) -> None:
        super(MoveCreateMeter, self).__init__(**kwargs)
        self.meter_code = meter_code
        self.meter_display = meter_display
        self.commodity = commodity
        self.serial_number = serial_number
