# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterCAPResponse(Model):
    """MeterCAPResponse.

    :param base_start: The meter's baseline start date
    :type base_start: datetime
    :param saving_start: The meter's savings start date
    :type saving_start: datetime
    :param include_in_cap: Indicates if the meter is included or not included
     in cost avoidance calculations
    :type include_in_cap: bool
    """

    _attribute_map = {
        'base_start': {'key': 'baseStart', 'type': 'iso-8601'},
        'saving_start': {'key': 'savingStart', 'type': 'iso-8601'},
        'include_in_cap': {'key': 'includeInCAP', 'type': 'bool'},
    }

    def __init__(self, *, base_start=None, saving_start=None, include_in_cap: bool=None, **kwargs) -> None:
        super(MeterCAPResponse, self).__init__(**kwargs)
        self.base_start = base_start
        self.saving_start = saving_start
        self.include_in_cap = include_in_cap
