# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SearchAccountChild(Model):
    """SearchAccountChild.

    :param result:
    :type result: ~energycap.sdk.models.SearchAccountChildSearchAccountChild
    """

    _attribute_map = {
        'result': {'key': 'result', 'type': 'SearchAccountChildSearchAccountChild'},
    }

    def __init__(self, **kwargs):
        super(SearchAccountChild, self).__init__(**kwargs)
        self.result = kwargs.get('result', None)
