# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ListActionReverse(Model):
    """ListActionReverse.

    :param batch_settings:
    :type batch_settings: ~energycap.sdk.models.BatchCreate
    """

    _attribute_map = {
        'batch_settings': {'key': 'batchSettings', 'type': 'BatchCreate'},
    }

    def __init__(self, *, batch_settings=None, **kwargs) -> None:
        super(ListActionReverse, self).__init__(**kwargs)
        self.batch_settings = batch_settings
