# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UtilityPlatform(Model):
    """UtilityPlatform.

    :param data_release_file_url: Date Release file Url used to record Data
     access release
    :type data_release_file_url: str
    """

    _attribute_map = {
        'data_release_file_url': {'key': 'dataReleaseFileUrl', 'type': 'str'},
    }

    def __init__(self, *, data_release_file_url: str=None, **kwargs) -> None:
        super(UtilityPlatform, self).__init__(**kwargs)
        self.data_release_file_url = data_release_file_url
