# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UDFSelectValueEntityResponse(Model):
    """UDFSelectValueEntityResponse.

    :param udf_select_value_id:  <span class='property-internal'>Required
     (defined)</span>
    :type udf_select_value_id: int
    :param value:  <span class='property-internal'>Required (defined)</span>
    :type value: str
    :param display_order:  <span class='property-internal'>Required
     (defined)</span>
    :type display_order: int
    """

    _attribute_map = {
        'udf_select_value_id': {'key': 'udfSelectValueId', 'type': 'int'},
        'value': {'key': 'value', 'type': 'str'},
        'display_order': {'key': 'displayOrder', 'type': 'int'},
    }

    def __init__(self, *, udf_select_value_id: int=None, value: str=None, display_order: int=None, **kwargs) -> None:
        super(UDFSelectValueEntityResponse, self).__init__(**kwargs)
        self.udf_select_value_id = udf_select_value_id
        self.value = value
        self.display_order = display_order
