# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BatchWorkflowSettings(Model):
    """BatchWorkflowSettings.

    :param batch_mode_enabled:
    :type batch_mode_enabled: bool
    :param due_date:
    :type due_date: ~energycap.sdk.models.BillHeaderWorkflowChild
    :param statement_date:
    :type statement_date: ~energycap.sdk.models.BillHeaderWorkflowChild
    :param invoice_number:
    :type invoice_number: ~energycap.sdk.models.BillHeaderWorkflowChild
    :param control_code:
    :type control_code: ~energycap.sdk.models.BillHeaderWorkflowChild
    :param next_reading:
    :type next_reading: ~energycap.sdk.models.BillHeaderWorkflowChild
    :param account_period_name:
    :type account_period_name: ~energycap.sdk.models.BillHeaderWorkflowChild
    :param account_period_year:
    :type account_period_year: ~energycap.sdk.models.BillHeaderWorkflowChild
    """

    _attribute_map = {
        'batch_mode_enabled': {'key': 'batchModeEnabled', 'type': 'bool'},
        'due_date': {'key': 'dueDate', 'type': 'BillHeaderWorkflowChild'},
        'statement_date': {'key': 'statementDate', 'type': 'BillHeaderWorkflowChild'},
        'invoice_number': {'key': 'invoiceNumber', 'type': 'BillHeaderWorkflowChild'},
        'control_code': {'key': 'controlCode', 'type': 'BillHeaderWorkflowChild'},
        'next_reading': {'key': 'nextReading', 'type': 'BillHeaderWorkflowChild'},
        'account_period_name': {'key': 'accountPeriodName', 'type': 'BillHeaderWorkflowChild'},
        'account_period_year': {'key': 'accountPeriodYear', 'type': 'BillHeaderWorkflowChild'},
    }

    def __init__(self, **kwargs):
        super(BatchWorkflowSettings, self).__init__(**kwargs)
        self.batch_mode_enabled = kwargs.get('batch_mode_enabled', None)
        self.due_date = kwargs.get('due_date', None)
        self.statement_date = kwargs.get('statement_date', None)
        self.invoice_number = kwargs.get('invoice_number', None)
        self.control_code = kwargs.get('control_code', None)
        self.next_reading = kwargs.get('next_reading', None)
        self.account_period_name = kwargs.get('account_period_name', None)
        self.account_period_year = kwargs.get('account_period_year', None)
