# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ExportFormatChild(Model):
    """ExportFormatChild.

    :param export_format_info:
    :type export_format_info: str
    :param preferred:
    :type preferred: bool
    """

    _attribute_map = {
        'export_format_info': {'key': 'exportFormatInfo', 'type': 'str'},
        'preferred': {'key': 'preferred', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(ExportFormatChild, self).__init__(**kwargs)
        self.export_format_info = kwargs.get('export_format_info', None)
        self.preferred = kwargs.get('preferred', None)
