# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class NotificationType(Model):
    """NotificationType.

    :param notification_type_id: The id of the notification type
    :type notification_type_id: int
    :param notification_type_info: The notification type name
    :type notification_type_info: str
    :param notification_type_description: A description of the notification
     type
    :type notification_type_description: str
    :param notification_category:
    :type notification_category: ~energycap.sdk.models.NotificationCategory
    """

    _attribute_map = {
        'notification_type_id': {'key': 'notificationTypeId', 'type': 'int'},
        'notification_type_info': {'key': 'notificationTypeInfo', 'type': 'str'},
        'notification_type_description': {'key': 'notificationTypeDescription', 'type': 'str'},
        'notification_category': {'key': 'notificationCategory', 'type': 'NotificationCategory'},
    }

    def __init__(self, *, notification_type_id: int=None, notification_type_info: str=None, notification_type_description: str=None, notification_category=None, **kwargs) -> None:
        super(NotificationType, self).__init__(**kwargs)
        self.notification_type_id = notification_type_id
        self.notification_type_info = notification_type_info
        self.notification_type_description = notification_type_description
        self.notification_category = notification_category
