# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceGroupDigestAreaRankingChild(Model):
    """PlaceGroupDigestAreaRankingChild.

    :param cost: The cost for this place
    :type cost: float
    :param use: The use for this place
    :type use: float
    :param value: The benchmark value for this place
    :type value: float
    :param area: The area for this place
    :type area: int
    :param savings_opportunity: The savings opportunity for this place
    :type savings_opportunity: float
    :param incomplete_data: Does this place have incomplete data?
    :type incomplete_data: bool
    :param place_id:
    :type place_id: int
    :param place_code:
    :type place_code: str
    :param place_info:
    :type place_info: str
    :param place_display:
    :type place_display: str
    :param include_in_charts:
    :type include_in_charts: bool
    """

    _attribute_map = {
        'cost': {'key': 'cost', 'type': 'float'},
        'use': {'key': 'use', 'type': 'float'},
        'value': {'key': 'value', 'type': 'float'},
        'area': {'key': 'area', 'type': 'int'},
        'savings_opportunity': {'key': 'savingsOpportunity', 'type': 'float'},
        'incomplete_data': {'key': 'incompleteData', 'type': 'bool'},
        'place_id': {'key': 'placeId', 'type': 'int'},
        'place_code': {'key': 'placeCode', 'type': 'str'},
        'place_info': {'key': 'placeInfo', 'type': 'str'},
        'place_display': {'key': 'placeDisplay', 'type': 'str'},
        'include_in_charts': {'key': 'includeInCharts', 'type': 'bool'},
    }

    def __init__(self, *, cost: float=None, use: float=None, value: float=None, area: int=None, savings_opportunity: float=None, incomplete_data: bool=None, place_id: int=None, place_code: str=None, place_info: str=None, place_display: str=None, include_in_charts: bool=None, **kwargs) -> None:
        super(PlaceGroupDigestAreaRankingChild, self).__init__(**kwargs)
        self.cost = cost
        self.use = use
        self.value = value
        self.area = area
        self.savings_opportunity = savings_opportunity
        self.incomplete_data = incomplete_data
        self.place_id = place_id
        self.place_code = place_code
        self.place_info = place_info
        self.place_display = place_display
        self.include_in_charts = include_in_charts
