# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceTypeResponse(Model):
    """PlaceTypeResponse.

    :param place_type_id: The place type identifier
    :type place_type_id: int
    :param place_type_code: The place type code
    :type place_type_code: str
    :param place_type_info: The place type info
    :type place_type_info: str
    :param structure: Indicates if the place is a structure
    :type structure: bool
    """

    _attribute_map = {
        'place_type_id': {'key': 'placeTypeId', 'type': 'int'},
        'place_type_code': {'key': 'placeTypeCode', 'type': 'str'},
        'place_type_info': {'key': 'placeTypeInfo', 'type': 'str'},
        'structure': {'key': 'structure', 'type': 'bool'},
    }

    def __init__(self, *, place_type_id: int=None, place_type_code: str=None, place_type_info: str=None, structure: bool=None, **kwargs) -> None:
        super(PlaceTypeResponse, self).__init__(**kwargs)
        self.place_type_id = place_type_id
        self.place_type_code = place_type_code
        self.place_type_info = place_type_info
        self.structure = structure
