# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillHeaderUpdateBillingPeriodChild(Model):
    """Billing Period.

    All required parameters must be populated in order to send to Azure.

    :param billing_period:  <span class='property-internal'>Required when
     Update is set to True</span>
    :type billing_period: int
    :param update: Required. Indicates whether or not the header value is
     being updated <span class='property-internal'>Required</span>
    :type update: bool
    """

    _validation = {
        'update': {'required': True},
    }

    _attribute_map = {
        'billing_period': {'key': 'billingPeriod', 'type': 'int'},
        'update': {'key': 'update', 'type': 'bool'},
    }

    def __init__(self, *, update: bool, billing_period: int=None, **kwargs) -> None:
        super(BillHeaderUpdateBillingPeriodChild, self).__init__(**kwargs)
        self.billing_period = billing_period
        self.update = update
