# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FixedUnitCostRequest(Model):
    """Fixed amount per unit to apply during bill calculation.

    All required parameters must be populated in order to send to Azure.

    :param unit_cost: Required. Fixed unit cost <span
     class='property-internal'>Required</span> <span class='property-info'>Max
     scale of 8</span>
    :type unit_cost: float
    :param unit_id: Required. Unit to which unit cost is applied <span
     class='property-internal'>Required</span>
    :type unit_id: int
    """

    _validation = {
        'unit_cost': {'required': True},
        'unit_id': {'required': True},
    }

    _attribute_map = {
        'unit_cost': {'key': 'unitCost', 'type': 'float'},
        'unit_id': {'key': 'unitId', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(FixedUnitCostRequest, self).__init__(**kwargs)
        self.unit_cost = kwargs.get('unit_cost', None)
        self.unit_id = kwargs.get('unit_id', None)
