# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ChargebackProcessorSettingsForAggregations(Model):
    """ChargebackProcessorSettingsForAggregations.

    :param billing_period: End period of Billing Period range to be processed
    :type billing_period: int
    :param note: Optional note/comment <span class='property-internal'>Must be
     between 0 and 255 characters</span>
    :type note: str
    :param batch_settings:
    :type batch_settings: ~energycap.sdk.models.BatchCreate
    """

    _validation = {
        'note': {'max_length': 255, 'min_length': 0},
    }

    _attribute_map = {
        'billing_period': {'key': 'billingPeriod', 'type': 'int'},
        'note': {'key': 'note', 'type': 'str'},
        'batch_settings': {'key': 'batchSettings', 'type': 'BatchCreate'},
    }

    def __init__(self, **kwargs):
        super(ChargebackProcessorSettingsForAggregations, self).__init__(**kwargs)
        self.billing_period = kwargs.get('billing_period', None)
        self.note = kwargs.get('note', None)
        self.batch_settings = kwargs.get('batch_settings', None)
