# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BenchmarkWithUsedCountResponse(Model):
    """BenchmarkWithUsedCountResponse.

    :param used_count: Number of times benchmark is used
    :type used_count: int
    :param benchmark_indicator: Indicator for which benchmark factor
    :type benchmark_indicator: int
    :param benchmark_info: benchmark info
    :type benchmark_info: str
    :param benchmark_category:
    :type benchmark_category: ~energycap.sdk.models.BenchmarkCategoryResponse
    """

    _attribute_map = {
        'used_count': {'key': 'usedCount', 'type': 'int'},
        'benchmark_indicator': {'key': 'benchmarkIndicator', 'type': 'int'},
        'benchmark_info': {'key': 'benchmarkInfo', 'type': 'str'},
        'benchmark_category': {'key': 'benchmarkCategory', 'type': 'BenchmarkCategoryResponse'},
    }

    def __init__(self, **kwargs):
        super(BenchmarkWithUsedCountResponse, self).__init__(**kwargs)
        self.used_count = kwargs.get('used_count', None)
        self.benchmark_indicator = kwargs.get('benchmark_indicator', None)
        self.benchmark_info = kwargs.get('benchmark_info', None)
        self.benchmark_category = kwargs.get('benchmark_category', None)
