# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TimeZoneChild(Model):
    """TimeZoneChild.

    :param time_zone_id:
    :type time_zone_id: int
    :param time_zone_code:
    :type time_zone_code: str
    :param time_zone_info:
    :type time_zone_info: str
    """

    _attribute_map = {
        'time_zone_id': {'key': 'timeZoneId', 'type': 'int'},
        'time_zone_code': {'key': 'timeZoneCode', 'type': 'str'},
        'time_zone_info': {'key': 'timeZoneInfo', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(TimeZoneChild, self).__init__(**kwargs)
        self.time_zone_id = kwargs.get('time_zone_id', None)
        self.time_zone_code = kwargs.get('time_zone_code', None)
        self.time_zone_info = kwargs.get('time_zone_info', None)
