# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReportDistributionChild(Model):
    """ReportDistributionChild.

    :param report_distribution_id: The id of the report distribution
    :type report_distribution_id: int
    :param report_distribution_name: The name of the report distribution
    :type report_distribution_name: str
    :param report_code: The report code to run as part of the report
     distribution
    :type report_code: str
    :param created_by_user:
    :type created_by_user: ~energycap.sdk.models.UserChild
    """

    _attribute_map = {
        'report_distribution_id': {'key': 'reportDistributionId', 'type': 'int'},
        'report_distribution_name': {'key': 'reportDistributionName', 'type': 'str'},
        'report_code': {'key': 'reportCode', 'type': 'str'},
        'created_by_user': {'key': 'createdByUser', 'type': 'UserChild'},
    }

    def __init__(self, **kwargs):
        super(ReportDistributionChild, self).__init__(**kwargs)
        self.report_distribution_id = kwargs.get('report_distribution_id', None)
        self.report_distribution_name = kwargs.get('report_distribution_name', None)
        self.report_code = kwargs.get('report_code', None)
        self.created_by_user = kwargs.get('created_by_user', None)
