# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Country(Model):
    """Country.

    :param country_id:
    :type country_id: int
    :param name:
    :type name: str
    :param alpha2_code:
    :type alpha2_code: str
    :param possible_spellings:
    :type possible_spellings: list[str]
    """

    _attribute_map = {
        'country_id': {'key': 'countryId', 'type': 'int'},
        'name': {'key': 'name', 'type': 'str'},
        'alpha2_code': {'key': 'alpha2Code', 'type': 'str'},
        'possible_spellings': {'key': 'possibleSpellings', 'type': '[str]'},
    }

    def __init__(self, *, country_id: int=None, name: str=None, alpha2_code: str=None, possible_spellings=None, **kwargs) -> None:
        super(Country, self).__init__(**kwargs)
        self.country_id = country_id
        self.name = name
        self.alpha2_code = alpha2_code
        self.possible_spellings = possible_spellings
