# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BatchChild(Model):
    """BatchChild.

    :param batch_id: The batch id.
    :type batch_id: int
    :param batch_code: The batch code.
    :type batch_code: str
    """

    _attribute_map = {
        'batch_id': {'key': 'batchId', 'type': 'int'},
        'batch_code': {'key': 'batchCode', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(BatchChild, self).__init__(**kwargs)
        self.batch_id = kwargs.get('batch_id', None)
        self.batch_code = kwargs.get('batch_code', None)
