# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ChannelLatestReading(Model):
    """ChannelLatestReading.

    :param observation_type:
    :type observation_type: ~energycap.sdk.models.ObservationTypeChildBase
    :param last_reading:
    :type last_reading: ~energycap.sdk.models.ReadingChildBase
    :param channel_id: The channel identifier
    :type channel_id: int
    :param interval: The channel interval in seconds.
     Monthly = 2592000
     Weekly = 604800
     Daily = 86400
     Hourly = 3600
     Thirty_Minutes = 1800
     Fifteen_Minutes = 900
    :type interval: int
    """

    _attribute_map = {
        'observation_type': {'key': 'observationType', 'type': 'ObservationTypeChildBase'},
        'last_reading': {'key': 'lastReading', 'type': 'ReadingChildBase'},
        'channel_id': {'key': 'channelId', 'type': 'int'},
        'interval': {'key': 'interval', 'type': 'int'},
    }

    def __init__(self, *, observation_type=None, last_reading=None, channel_id: int=None, interval: int=None, **kwargs) -> None:
        super(ChannelLatestReading, self).__init__(**kwargs)
        self.observation_type = observation_type
        self.last_reading = last_reading
        self.channel_id = channel_id
        self.interval = interval
