# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterGroupMember(Model):
    """MeterGroupMember.

    :param meter_group_id: The meter group this meter will belong to <span
     class='property-internal'>Required (defined)</span>
    :type meter_group_id: int
    :param include_in_charts: Whether to include this meter in the group's
     benchmark charts <span class='property-internal'>Required (defined)</span>
    :type include_in_charts: bool
    """

    _attribute_map = {
        'meter_group_id': {'key': 'meterGroupId', 'type': 'int'},
        'include_in_charts': {'key': 'includeInCharts', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(MeterGroupMember, self).__init__(**kwargs)
        self.meter_group_id = kwargs.get('meter_group_id', None)
        self.include_in_charts = kwargs.get('include_in_charts', None)
