# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ObservationType(Model):
    """ObservationType.

    :param observation_type_id:
    :type observation_type_id: int
    :param credit:
    :type credit: int
    :param time_of_use:
    :type time_of_use: int
    :param creation:
    :type creation: int
    :param noun:
    :type noun: int
    :param observation_type_code:  <span class='property-internal'>Must be
     between 0 and 16 characters</span>
    :type observation_type_code: str
    :param observation_type_info:  <span class='property-internal'>Must be
     between 0 and 32 characters</span>
    :type observation_type_info: str
    """

    _validation = {
        'observation_type_code': {'max_length': 16, 'min_length': 0},
        'observation_type_info': {'max_length': 32, 'min_length': 0},
    }

    _attribute_map = {
        'observation_type_id': {'key': 'observationTypeId', 'type': 'int'},
        'credit': {'key': 'credit', 'type': 'int'},
        'time_of_use': {'key': 'timeOfUse', 'type': 'int'},
        'creation': {'key': 'creation', 'type': 'int'},
        'noun': {'key': 'noun', 'type': 'int'},
        'observation_type_code': {'key': 'observationTypeCode', 'type': 'str'},
        'observation_type_info': {'key': 'observationTypeInfo', 'type': 'str'},
    }

    def __init__(self, *, observation_type_id: int=None, credit: int=None, time_of_use: int=None, creation: int=None, noun: int=None, observation_type_code: str=None, observation_type_info: str=None, **kwargs) -> None:
        super(ObservationType, self).__init__(**kwargs)
        self.observation_type_id = observation_type_id
        self.credit = credit
        self.time_of_use = time_of_use
        self.creation = creation
        self.noun = noun
        self.observation_type_code = observation_type_code
        self.observation_type_info = observation_type_info
