# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DataAccessReleaseStatus(Model):
    """DataAccessReleaseStatus.

    :param data_access_release_status_id: Id of the Data Access Release Status
     Possible values are:
     1 - Not Applicable
     2 - Required
     3 - Pending
     4 - Released
    :type data_access_release_status_id: int
    :param data_access_release_status_info: Data Access Release Status
     Information
     Possible values are:
     Not Applicable
     Required
     Pending
     Released
    :type data_access_release_status_info: str
    """

    _attribute_map = {
        'data_access_release_status_id': {'key': 'dataAccessReleaseStatusId', 'type': 'int'},
        'data_access_release_status_info': {'key': 'dataAccessReleaseStatusInfo', 'type': 'str'},
    }

    def __init__(self, *, data_access_release_status_id: int=None, data_access_release_status_info: str=None, **kwargs) -> None:
        super(DataAccessReleaseStatus, self).__init__(**kwargs)
        self.data_access_release_status_id = data_access_release_status_id
        self.data_access_release_status_info = data_access_release_status_info
