# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarRatingChild(Model):
    """EnergyStarRatingChild.

    :param rating_date: The date the score was received
    :type rating_date: datetime
    :param calendar_period: The year and month for the ENERGY STAR score
    :type calendar_period: int
    :param rating: The ENERGY STAR score
    :type rating: int
    :param site_energy_use_intensity: The weather-normalized property energy
     use intensity (kBtu/ft²)
    :type site_energy_use_intensity: float
    """

    _attribute_map = {
        'rating_date': {'key': 'ratingDate', 'type': 'iso-8601'},
        'calendar_period': {'key': 'calendarPeriod', 'type': 'int'},
        'rating': {'key': 'rating', 'type': 'int'},
        'site_energy_use_intensity': {'key': 'siteEnergyUseIntensity', 'type': 'float'},
    }

    def __init__(self, *, rating_date=None, calendar_period: int=None, rating: int=None, site_energy_use_intensity: float=None, **kwargs) -> None:
        super(EnergyStarRatingChild, self).__init__(**kwargs)
        self.rating_date = rating_date
        self.calendar_period = calendar_period
        self.rating = rating
        self.site_energy_use_intensity = site_energy_use_intensity
