# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CalculationRequest(Model):
    """Adding/subtracting calculation involving meters and/or meter groups
    You must pass in at least 1 thing to sum or subtract.

    :param sum:
    :type sum: ~energycap.sdk.models.SumRequest
    :param subtract:
    :type subtract: ~energycap.sdk.models.SubtractRequest
    """

    _attribute_map = {
        'sum': {'key': 'sum', 'type': 'SumRequest'},
        'subtract': {'key': 'subtract', 'type': 'SubtractRequest'},
    }

    def __init__(self, *, sum=None, subtract=None, **kwargs) -> None:
        super(CalculationRequest, self).__init__(**kwargs)
        self.sum = sum
        self.subtract = subtract
