# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UnitType(Model):
    """UnitType.

    :param unit_type_id:
    :type unit_type_id: int
    :param unit_type_code:
    :type unit_type_code: str
    :param unit_type_info:
    :type unit_type_info: str
    """

    _attribute_map = {
        'unit_type_id': {'key': 'unitTypeId', 'type': 'int'},
        'unit_type_code': {'key': 'unitTypeCode', 'type': 'str'},
        'unit_type_info': {'key': 'unitTypeInfo', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(UnitType, self).__init__(**kwargs)
        self.unit_type_id = kwargs.get('unit_type_id', None)
        self.unit_type_code = kwargs.get('unit_type_code', None)
        self.unit_type_info = kwargs.get('unit_type_info', None)
