# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestGHGMonthlyResponseGHGScope(Model):
    """PlaceDigestGHGMonthlyResponseGHGScope.

    :param ghg_scope_id: GHG scope identifier
    :type ghg_scope_id: int
    :param ghg_scope_code: GHG scope code
    :type ghg_scope_code: str
    :param ghg_scope_info: GHG scope info
    :type ghg_scope_info: str
    :param target_comparison:
    :type target_comparison:
     ~energycap.sdk.models.PlaceDigestGHGMonthlyResponseTargetComparison
    :param results: An array of monthly data
    :type results:
     list[~energycap.sdk.models.PlaceDigestGHGMonthlyResponseResults]
    """

    _attribute_map = {
        'ghg_scope_id': {'key': 'ghgScopeId', 'type': 'int'},
        'ghg_scope_code': {'key': 'ghgScopeCode', 'type': 'str'},
        'ghg_scope_info': {'key': 'ghgScopeInfo', 'type': 'str'},
        'target_comparison': {'key': 'targetComparison', 'type': 'PlaceDigestGHGMonthlyResponseTargetComparison'},
        'results': {'key': 'results', 'type': '[PlaceDigestGHGMonthlyResponseResults]'},
    }

    def __init__(self, **kwargs):
        super(PlaceDigestGHGMonthlyResponseGHGScope, self).__init__(**kwargs)
        self.ghg_scope_id = kwargs.get('ghg_scope_id', None)
        self.ghg_scope_code = kwargs.get('ghg_scope_code', None)
        self.ghg_scope_info = kwargs.get('ghg_scope_info', None)
        self.target_comparison = kwargs.get('target_comparison', None)
        self.results = kwargs.get('results', None)
