# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdjustmentBaseMethodChild(Model):
    """AdjustmentBaseMethodChild.

    :param special_adjustment_method_id: Special adjustment method identifier
    :type special_adjustment_method_id: int
    :param label: Special adjustment method description
    :type label: str
    """

    _attribute_map = {
        'special_adjustment_method_id': {'key': 'specialAdjustmentMethodId', 'type': 'int'},
        'label': {'key': 'label', 'type': 'str'},
    }

    def __init__(self, *, special_adjustment_method_id: int=None, label: str=None, **kwargs) -> None:
        super(AdjustmentBaseMethodChild, self).__init__(**kwargs)
        self.special_adjustment_method_id = special_adjustment_method_id
        self.label = label
